@@ -6,6 +6,8 @@ if [ -n "${EZ_VERBOSE}" ]; then
     set -x
 fi
 
+USE_TASKSMAX=${USE_TASKSMAX:-true}
+
 # Warning: This variable API is experimental so these variables may be subject
 # to change in the future.
 prefix=${prefix:=/usr}
@@ -129,6 +131,22 @@ function task_install_source_deb_systemd {
     task postinst_deb
 }
 
+# install docs for debian based systems
+function task_install_docs_deb {
+  if [ -d ext/docs ]; then
+    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver"
+    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver"
+  fi
+}
+
+# install docs for rpm based systems
+function task_install_docs_rpm {
+  if [ -d ext/docs ]; then
+    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver-7.11.0"
+    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver-7.11.0"
+  fi
+}
+
 # Install the ezbake package software. This step is used during RPM &
 # Debian packaging during the 'install' phases.
 function task_install {
@@ -139,8 +157,6 @@ function task_install {
     install -m 0644 ext/ezbake.manifest "${dest_apps_dir}"
     install -d -m 0755 "${DESTDIR}${projconfdir}/conf.d"
 
-      install -m 0644 jruby-9k.jar "${dest_apps_dir}"
-      install -m 0644 jruby-1_7.jar "${dest_apps_dir}"
   
     install -d -m 0755 "${DESTDIR}${system_config_dir}/services.d"
     install -d -m 0755 "${DESTDIR}${projconfdir}/services.d"
@@ -154,6 +170,7 @@ function task_install {
     install -m 0644 ext/config/conf.d/web-routes.conf "${DESTDIR}${projconfdir}/conf.d/web-routes.conf"
     install -m 0644 ext/config/conf.d/auth.conf "${DESTDIR}${projconfdir}/conf.d/auth.conf"
     install -m 0644 ext/config/conf.d/metrics.conf "${DESTDIR}${projconfdir}/conf.d/metrics.conf"
+    install -m 0644 ext/config/conf.d/ca.conf "${DESTDIR}${projconfdir}/conf.d/ca.conf"
     install -m 0644 ext/config/conf.d/webserver.conf "${DESTDIR}${projconfdir}/conf.d/webserver.conf"
     install -m 0644 ext/config/services.d/ca.cfg "${DESTDIR}${projconfdir}/services.d/ca.cfg"
 
@@ -168,13 +185,15 @@ function task_install {
     ln -s "../apps/${real_name}/bin/${real_name}" "${DESTDIR}${symbindir}/${real_name}"
     install -d -m 0755 "${DESTDIR}${uxbindir}"
     ln -s "../server/apps/${real_name}/bin/${real_name}" "${DESTDIR}${uxbindir}/${real_name}"
-    install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
-    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
-    install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
-    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
     install -m 0755 ext/cli/gem "${dest_apps_dir}/cli/apps/gem"
+    install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
+    install -m 0755 ext/cli/ca "${dest_apps_dir}/cli/apps/ca"
     install -m 0755 ext/cli/irb "${dest_apps_dir}/cli/apps/irb"
     install -m 0755 ext/cli/ruby "${dest_apps_dir}/cli/apps/ruby"
+    install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
+    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
+    install -m 0755 ext/cli/dropsonde "${dest_apps_dir}/cli/apps/dropsonde"
+    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
 
 if [ -e "ext/cli_defaults/cli-defaults.sh" ]; then
     install -m 0755 ext/cli_defaults/cli-defaults.sh "${dest_apps_dir}/cli/"
@@ -187,11 +206,13 @@ fi
 
 function task_install_redhat {
     task install
+    task install_docs_rpm
     bash ./ext/build-scripts/install-vendored-gems.sh
 }
 
 function task_install_deb {
     task install
+    task install_docs_deb
     bash ./ext/build-scripts/install-vendored-gems.sh
 }
 
@@ -242,6 +263,9 @@ function task_systemd_deb {
     task sysv_init_deb
     install -d -m 0755 "${DESTDIR}${unitdir_debian}"
     install -m 0644 ext/debian/puppetserver.service_file "${DESTDIR}${unitdir_debian}/puppetserver.service"
+    if [ "$USE_TASKSMAX" == "false" ]; then
+      sed -i "s/^TasksMax/# Don't set TasksMax since the option doesn't exist\n# TasksMax/" "${DESTDIR}${unitdir_debian}/puppetserver.service"
+    fi
     install -d -m 0755 "${DESTDIR}${tmpfilesdir}"
     install -m 0644 ext/puppetserver.tmpfiles.conf "${DESTDIR}${tmpfilesdir}/puppetserver.conf"
 }
@@ -276,9 +300,14 @@ function task_preinst_deb {
     task service_account
 }
 
-# Debian based post-installation tasks.
+# Debian based unconditional post-installation tasks.
 function task_postinst_deb {
     task postinst_permissions
+}
+
+# Debian based install post-installation tasks.
+function task_postinst_deb_install {
+    : # Null command in case additional_postinst_install is empty
     install --owner=puppet --group=puppet -d /opt/puppetlabs/server/data/puppetserver/jruby-gems
     /opt/puppetlabs/puppet/bin/puppet config set --section master vardir  /opt/puppetlabs/server/data/puppetserver
     /opt/puppetlabs/puppet/bin/puppet config set --section master logdir  /var/log/puppetlabs/puppetserver
@@ -292,9 +321,14 @@ function task_postinst_deb {
     find /etc/puppetlabs/puppet/ssl -type d -print0 | xargs -0 chmod 770
 }
 
-# RPM based post-installation tasks.
+# RPM based unconditional post-installation tasks.
 function task_postinst_redhat {
     : # Null command in case additional_postinst is empty
+}
+
+# RPM based install post-installation tasks.
+function task_postinst_redhat_install {
+    : # Null command in case additional_postinst_install is empty
     install --owner=puppet --group=puppet -d /opt/puppetlabs/server/data/puppetserver/jruby-gems
     /opt/puppetlabs/puppet/bin/puppet config set --section master vardir  /opt/puppetlabs/server/data/puppetserver
     /opt/puppetlabs/puppet/bin/puppet config set --section master logdir  /var/log/puppetlabs/puppetserver
