@@ -24,9 +24,6 @@
           path (get-route this)
           config (get-config)
           puppet-version (get-in config [:puppetserver :puppet-version])
-          use-legacy-auth-conf (get-in config
-                                       [:jruby-puppet :use-legacy-auth-conf]
-                                       false)
           master-service (tk-services/get-service this :MasterService)
           master-ns (keyword (tk-services/service-symbol master-service))
           master-metrics (-> master-service
@@ -38,20 +35,26 @@
           jruby-service (tk-services/get-service this :JRubyPuppetService)
           master-routes (comidi/context path
                                         (master-core/root-routes handle-request
-                                                                 (partial identity)
+                                                                 identity
                                                                  jruby-service
+                                                                 identity
+                                                                 (fn [_ _ _]
+                                                                   (throw (IllegalStateException.
+                                                                            (i18n/trs "Versioned code not supported."))))
                                                                  (constantly nil)
-                                                                 false))
+                                                                 false
+                                                                 nil
+                                                                 nil
+                                                                 nil))
           master-route-handler (comidi/routes->handler master-routes)
           master-mount (master-core/get-master-mount
                         master-ns
                         master-route-config)
           master-handler-info {:mount master-mount
-                               :handler (-> (master-core/get-wrapped-handler
+                               :handler (-> (master-core/wrap-middleware
                                              master-route-handler
                                              (get-auth-handler)
-                                             puppet-version
-                                             use-legacy-auth-conf)
+                                             puppet-version)
                                             (http-metrics/wrap-with-request-metrics
                                              master-metrics)
                                             (legacy-routes-core/add-root-path-to-route-id
