@@ -1,12 +1,10 @@
 (ns puppetlabs.services.master.master-service
   (:require [clojure.tools.logging :as log]
-            [ring.middleware.params :as ring]
             [puppetlabs.trapperkeeper.core :refer [defservice]]
-            [puppetlabs.services.master.master-core :as core]
             [puppetlabs.puppetserver.certificate-authority :as ca]
+            [puppetlabs.puppetserver.jruby-request :as jruby-request]
             [puppetlabs.trapperkeeper.services :as tk-services]
             [puppetlabs.comidi :as comidi]
-            [puppetlabs.dujour.version-check :as version-check]
             [puppetlabs.metrics.http :as http-metrics]
             [puppetlabs.services.protocols.master :as master]
             [puppetlabs.i18n.core :as i18n]
@@ -78,6 +76,25 @@
    default-jvm-metrics-allowed
    http-client-metrics-allowed-hists))
 
+(defn jdk-support-status
+  "Returns :official, :deprecated, :unknown, or :unsupported."
+  [version]
+  (cond
+    (re-matches #"1\.[1234567]($|(\..*))" version) :unsupported
+    (re-matches #"1\.[89]($|(\..*))" version) :deprecated
+    (re-matches #"10($|(\..*))" version) :deprecated
+    (re-matches (re-pattern (str 11 "($|(\\..*))")) version) :official
+    (re-matches #"17($|(\..*))" version) :official
+    :else :unknown))
+
+(defn log-java-deprecation-message [version]
+  (let [status (jdk-support-status version)]
+    (case status
+      (:unknown) (log/warn (i18n/trs "JDK {0} is neither tested nor supported. Please use JDK 11 or 17" version))
+      (:deprecated) (log/warn (i18n/trs "JDK {0} is deprecated, please upgrade to JDK 11 or 17" version))
+      (:official) nil
+      (:unsupported) (log/warn (i18n/trs "Puppetserver doesn't support JDK {0}" version)))))
+
 (defservice master-service
   master/MasterService
   [[:WebroutingService add-ring-handler get-route]
@@ -89,41 +106,50 @@
    [:AuthorizationService wrap-with-authorization-check]
    [:SchedulerService interspaced]
    [:StatusService register-status]
-   [:VersionedCodeService get-code-content]]
+   [:VersionedCodeService get-code-content current-code-id]]
   (init
    [this context]
-   (core/validate-memory-requirements!)
+   (master-core/validate-memory-requirements!)
    (let [config (get-config)
-         route-config (core/get-master-route-config ::master-service config)
-         path (core/get-master-mount ::master-service route-config)
+         route-config (master-core/get-master-route-config ::master-service config)
+         path (master-core/get-master-mount ::master-service route-config)
          certname (get-in config [:puppetserver :certname])
          localcacert (get-in config [:puppetserver :localcacert])
          puppet-version (get-in config [:puppetserver :puppet-version])
+         bolt-builtin-content-dir (get-in config [:bolt :builtin-content-dir] [])
+         bolt-projects-dir (get-in config [:bolt :projects-dir])
+         max-queued-requests (get-in config [:jruby-puppet :max-queued-requests] 0)
+         max-retry-delay (get-in config [:jruby-puppet :max-retry-delay] 1800)
          settings (ca/config->master-settings config)
+         metrics-service (tk-services/get-service this :JRubyMetricsService)
          metrics-server-id (get-server-id)
          jruby-service (tk-services/get-service this :JRubyPuppetService)
-         use-legacy-auth-conf (get-in config
-                                      [:jruby-puppet :use-legacy-auth-conf]
-                                      false)
-         clojure-handler (fn [handler]
-                           (core/get-wrapped-handler
-                            (ring/wrap-params handler)
-                            (get-auth-handler)
-                            puppet-version))
          environment-class-cache-enabled (get-in config
                                                  [:jruby-puppet
                                                   :environment-class-cache-enabled]
                                                  false)
+         wrap-with-jruby-queue-limit (if (pos? max-queued-requests)
+                                       (fn [handler]
+                                         (jruby-request/wrap-with-request-queue-limit
+                                          handler
+                                          metrics-service
+                                          max-queued-requests
+                                          max-retry-delay))
+                                       identity)
+
+         boltlib-path (get-in config [:jruby-puppet :boltlib-path])
          ring-app (comidi/routes
-                   (core/construct-root-routes puppet-version
-                                               use-legacy-auth-conf
+                   (master-core/construct-root-routes puppet-version
                                                jruby-service
                                                get-code-content
+                                               current-code-id
                                                handle-request
                                                (get-auth-handler)
-                                               environment-class-cache-enabled)
-                   (-> (core/experimental-routes path)
-                       (comidi/wrap-routes clojure-handler)))
+                                               wrap-with-jruby-queue-limit
+                                               environment-class-cache-enabled
+                                               boltlib-path
+                                               bolt-builtin-content-dir
+                                               bolt-projects-dir))
          routes (comidi/context path ring-app)
          route-metadata (comidi/route-metadata routes)
          comidi-handler (comidi/routes->handler routes)
@@ -137,12 +163,12 @@
                           (http-metrics/wrap-with-request-metrics http-metrics)
                           (comidi/wrap-with-route-metadata routes))
          hostcrl (get-in config [:puppetserver :hostcrl])]
-
+     (log-java-deprecation-message (System/getProperty "java.version"))
      (retrieve-ca-cert! localcacert)
      (retrieve-ca-crl! hostcrl)
      (initialize-master-ssl! settings certname)
 
-     (core/register-jvm-metrics! registry metrics-server-id)
+     (master-core/register-jvm-metrics! registry metrics-server-id)
 
      (update-registry-settings :puppetserver
                                {:default-metrics-allowed default-metrics-allowed})
@@ -171,7 +197,12 @@
       "master"
       (status-core/get-artifact-version "puppetlabs" "puppetserver")
       master-service-status-version
-      (partial core/v1-status http-metrics http-client-metric-ids-for-status registry))
+      (partial master-core/v1-status http-metrics http-client-metric-ids-for-status registry))
+     (register-status
+      "server"
+      (status-core/get-artifact-version "puppetlabs" "puppetserver")
+      master-service-status-version
+      (partial master-core/v1-status http-metrics http-client-metric-ids-for-status registry))
      (-> context
          (assoc :http-metrics http-metrics)
          (assoc :http-client-metric-ids-for-status http-client-metric-ids-for-status))))
